@@ -1,5 +1,5 @@
 package Kayako::RestAPI;
-$Kayako::RestAPI::VERSION = '0.02';
+$Kayako::RestAPI::VERSION = '0.03';
 # ABSTRACT: Perl library for working with L<Kayako REST API|https://kayako.atlassian.net/wiki/display/DEV/Kayako+REST+API>
 
 
@@ -202,7 +202,7 @@ Kayako::RestAPI - Perl library for working with L<Kayako REST API|https://kayako
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -290,15 +290,33 @@ Check a list of required arguments here: L<https://kayako.atlassian.net/wiki/dis
 
 =head2 filter_fields
 
-Filter fields of API request result
+Filter fields of API request result and trim content_key
 
 By default leave only id, title and module fields
 
+    my $arrayref = $kayako_api->get_hash('/Some/API/Endpoint');
     $kayako_api->filter_fields($arrayref); 
 
 =head2 get_departements
 
-$kayako_api->get_departements(); # return an arrayref
+    $kayako_api->get_departements();
+
+Return an arrayref of hashes with title, module and id keys like
+
+[
+    {
+        'module' => 'tickets',
+        'title' => 'Hard drives department',
+        'id' => '5'
+    },
+    {
+        'id' => '6',
+        'module' => 'tickets',
+        'title' => 'Flash drives department'
+    }
+]
+
+API endpoint is /Base/Department/
 
 =head2 get_ticket_statuses
 
@@ -306,20 +324,22 @@ $kayako_api->get_departements(); # return an arrayref
 
 Return an arrayref of hashes with title and id keys like
 
-[
-    {
-        'title' => 'In progress',
-        'id' => '1'
-    },
-    {
-        'title' => 'Closed',
-        'id' => '3'
-    },
-    {
-        'id' => '4',
-        'title' => 'New'
-    }
-]
+    [
+        {
+            'title' => 'In progress',
+            'id' => '1'
+        },
+        {
+            'title' => 'Closed',
+            'id' => '3'
+        },
+        {
+            'id' => '4',
+            'title' => 'New'
+        }
+    ]
+
+API endpoint is /Tickets/TicketStatus/
 
 =head2 get_ticket_priorities
 
@@ -338,6 +358,8 @@ Return an arrayref of hashes with title and id keys like
         },
     ]
 
+API endpoint is /Tickets/TicketPriority/
+
 =head2 get_ticket_types
 
     $kayako_api->get_ticket_types();
@@ -359,7 +381,7 @@ Return an arrayref of hashes with title and id keys like
     }
 ];
 
-See more: 
+API endpoint is /Tickets/TicketType/
 
 =head2 get_staff
 
@@ -378,7 +400,7 @@ E.g.
             'lastname' => { 'text' => 'Serikov' },
             'enabledst' => { 'text' => '0'},
             'username' => { 'text' => 'pavelsr' },
-            'isenabled' => { 'text' => '1' },
+            'isenabled' => { 'text' => '1' }6,
             'staffgroupid' => { 'text' => '4' },
             'greeting' => {},
             'timezone' => {},
@@ -389,13 +411,15 @@ E.g.
         }
     ]
 
+API endpoint is /Base/Staff/
+
 =head1 AUTHOR
 
 Pavel Serikov <pavelsr@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Pavel Serikov.
+This software is copyright (c) 2018 by Pavel Serikov.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
